@@ -176,7 +176,7 @@ def _oneShotErrorUse(expression, field=None, chunkTest=False):
                     else:
                         break
 
-                    if output:
+                    if output and conf.verbose in (1, 2) and not conf.api:
                         if kb.fileReadMode:
                             dataToStdout(_formatPartialContent(output).replace(r"\n", "\n").replace(r"\t", "\t"))
                         elif offset > 1:
@@ -301,7 +301,7 @@ def errorUse(expression, dump=False):
     _, _, _, _, _, expressionFieldsList, expressionFields, _ = agent.getFields(expression)
 
     # Set kb.partRun in case the engine is called from the API
-    kb.partRun = getPartRun(alias=False) if hasattr(conf, "api") else None
+    kb.partRun = getPartRun(alias=False) if conf.api else None
 
     # We have to check if the SQL query might return multiple entries
     # and in such case forge the SQL limiting the query output one
@@ -358,9 +358,8 @@ def errorUse(expression, dump=False):
             if " ORDER BY " in expression and (stopLimit - startLimit) > SLOW_ORDER_COUNT_THRESHOLD:
                 message = "due to huge table size do you want to remove "
                 message += "ORDER BY clause gaining speed over consistency? [y/N] "
-                _ = readInput(message, default="N")
 
-                if _ and _[0] in ("y", "Y"):
+                if readInput(message, default="N", boolean=True):
                     expression = expression[:expression.index(" ORDER BY ")]
 
             numThreads = min(conf.threads, (stopLimit - startLimit))
@@ -422,8 +421,8 @@ def errorUse(expression, dump=False):
                             index = None
                             if threadData.shared.showEta:
                                 threadData.shared.progress.progress(time.time() - valueStart, threadData.shared.counter)
-                            for index in xrange(len(threadData.shared.buffered)):
-                                if threadData.shared.buffered[index][0] >= num:
+                            for index in xrange(1 + len(threadData.shared.buffered)):
+                                if index < len(threadData.shared.buffered) and threadData.shared.buffered[index][0] >= num:
                                     break
                             threadData.shared.buffered.insert(index or 0, (num, output))
                             while threadData.shared.buffered and threadData.shared.lastFlushed + 1 == threadData.shared.buffered[0][0]:
