@@ -20,6 +20,7 @@ from lib.core.common import getSafeExString
 from lib.core.common import openFile
 from lib.core.common import readInput
 from lib.core.common import safeCSValue
+from lib.core.common import urldecode
 from lib.core.data import conf
 from lib.core.data import kb
 from lib.core.data import logger
@@ -87,7 +88,7 @@ def crawl(target):
                         tags = soup('a')
 
                         if not tags:
-                            tags = re.finditer(r'(?si)<a[^>]+href="(?P<href>[^>"]+)"', content)
+                            tags = re.finditer(r'(?i)<a[^>]+href="(?P<href>[^>"]+)"', content)
 
                         for tag in tags:
                             href = tag.get("href") if hasattr(tag, "get") else tag.group("href")
@@ -130,8 +131,8 @@ def crawl(target):
         if not conf.sitemapUrl:
             message = "do you want to check for the existence of "
             message += "site's sitemap(.xml) [y/N] "
-            test = readInput(message, default="n")
-            if test[0] in ("y", "Y"):
+
+            if readInput(message, default='N', boolean=True):
                 found = True
                 items = None
                 url = urlparse.urljoin(target, "/sitemap.xml")
@@ -187,7 +188,7 @@ def crawl(target):
             logger.warn(warnMsg)
         else:
             for url in threadData.shared.value:
-                kb.targets.add((url, None, None, None, None))
+                kb.targets.add((urldecode(url, kb.pageEncoding), None, None, None, None))
 
         storeResultsToFile(kb.targets)
 
@@ -198,8 +199,8 @@ def storeResultsToFile(results):
     if kb.storeCrawlingChoice is None:
         message = "do you want to store crawling results to a temporary file "
         message += "for eventual further processing with other tools [y/N] "
-        test = readInput(message, default="N")
-        kb.storeCrawlingChoice = test[0] in ("y", "Y")
+
+        kb.storeCrawlingChoice = readInput(message, default='N', boolean=True)
 
     if kb.storeCrawlingChoice:
         handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.CRAWLER, suffix=".csv" if conf.forms else ".txt")
